@@ -263,7 +263,8 @@ module TZInfo
       timezone 'Asia/Kamchatka'
       timezone 'Asia/Karachi'
       timezone 'Asia/Kashgar'
-      timezone 'Asia/Katmandu'
+      timezone 'Asia/Kathmandu'
+      linked_timezone 'Asia/Katmandu'
       timezone 'Asia/Kolkata'
       timezone 'Asia/Krasnoyarsk'
       timezone 'Asia/Kuala_Lumpur'
